# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'supersecretkey'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = ['*']

BOM_CONFIG = {
    'octopart_api_key': '46b1a32d',
}

# google GoogleOAuth
SOCIAL_AUTH_GOOGLE_OAUTH2_KEY = '449904336434-mlab3bm7v0fvvocbb8qifg19vjr66fun.apps.googleusercontent.com'
SOCIAL_AUTH_GOOGLE_OAUTH2_SECRET = 'uwEEKQEPeoGIIXM9OWuNlARB'